aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--profiles/http/src/main/java/org/onap/cli/fw/http/cmd/OnapHttpCommand.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/profiles/http/src/main/java/org/onap/cli/fw/http/cmd/OnapHttpCommand.java b/profiles/http/src/main/java/org/onap/cli/fw/http/cmd/OnapHttpCommand.java
index b4654cc8..d18090b1 100644
--- a/profiles/http/src/main/java/org/onap/cli/fw/http/cmd/OnapHttpCommand.java
+++ b/profiles/http/src/main/java/org/onap/cli/fw/http/cmd/OnapHttpCommand.java
@@ -218,7 +218,7 @@ public class OnapHttpCommand extends OnapCommand {
if (isAuthRequired) {
this.authClient.logout();
}
- } catch (OnapCommandException e) {
+ } catch (OnapCommandException e) { //NOSONAR
throw e;
} finally {
this.getResult().setDebugInfo(this.input.toString() + "\n" + this.output.toString());
@@ -262,7 +262,7 @@ public class OnapHttpCommand extends OnapCommand {
try{
generateJsonMock(this.getInput(), output, this.getSchemaName());
} catch (OnapCommandFailedMocoGenerate e) {
//NO SONAR ignore it
}
}
@@ -262,7 +262,7 @@ public class OnapHttpCommand extends OnapCommand {
generateJsonMock(this.getInput(), output, this.getSchemaName());
} catch (OnapCommandFailedMocoGenerate e) {
- //NO SONAR ignore it
+ //NOSONAR ignore it
}
}